# args: workdir
mst_otsb_vcs_hg_tags () {

    hg -R "$1" tags

}

# args: workdir
mst_otsb_vcs_git_tags () (

    cd "$1"
    git tag

)


# args: workdir
mst_otsb_vcs_hg_version () {

    hg -R "$1" log -r tip --template '{node|short}'

}

mst_otsb_vcs_git_version () (

    cd "$1"
    git log -n 1 --pretty=format:'%h'

)

# args: src destdir package_name branch/tag
mst_otsb_vcs_hg_clone () {

    local src=$1
    local destdir=$2
    local package_name=${3:-$(basename $src)}
    local tag=${4:-default}

    hg -q clone "$src" "$destdir"

    hg -q -R "$destdir" update -r $tag
}

# args: src destdir package_name branch/tag
mst_otsb_vcs_git_clone () {

    local src=$1
    local destdir=$2
    local package_name=${3:-$(basename $src .git)}
    local branch=${4:-master}

    git clone -q $src $destdir

    GIT_WORK_TREE=$destdir \
	GIT_DIR=$destdir/.git \
	git checkout -q $branch
}


# args: cmd args
mst_otsb_vcs () {

    local vcs=$1
    local cmd=$2
    shift 2

    local proxy=mst_otsb_vcs_${vcs}_${cmd}

    if ! otsb_has_command $proxy ; then
	otsb_die "unsupported vcs or command: $vcs $cmd"
    fi

    eval $proxy "${@}"
}


# args: vcs src package_name branch/tag
mst_otsb_vcs_tarball_from_clone () {

    local vcs=$1
    local src=$2
    shift 2
    local package_name=${1:-$(basename $src .git)}

    local tmpdir=$(otsb_mktemp_dir) \
	|| otsb_die "unable to create temporary directory"

    local destdir=$tmpdir/src
    mkdir "$destdir"

    mst_otsb_vcs $vcs clone "$src" "$destdir" "${@}"

    local version=$(mst_otsb_vcs $vcs version "$destdir")
    local package="$package_name-$version"
    local tarball="$package.tar.gz"

    rsync -a $destdir/ $tmpdir/$package
    tar -C $tmpdir -czf $tarball $package

    /bin/rm -rf $tmpdir

    echo $tarball
}

# args: vcs src package_name branch/tag
mst_otsb_vcs_archive_from_clone  () {

    local src="$1"
    local package_name=${2:-$(basename $src)}
    local tag=${3:-default}

    local tarball=$(mst_otsb_vcs_tarball_from_clone "${@}" ) \
	|| otsb_die "error retrieving tarball for $package_name from $src"

    mst_otsb_set_latest_archive "$tarball"

}

mst_otsb_set_latest_archive () (

    local tarball=$1

    cd "$otsbv_import_root"

    rm -f latest
    ln -s $tarball latest
    unset otsbv_archive
    mst_otsb_set_archive

)
